pub struct TaskPlanner<'a> { /* private fields */ }Implementations
Sourceimpl<'a> TaskPlanner<'a>
impl<'a> TaskPlanner<'a>
pub fn new( pool: &'a Pool<Postgres>, channel: &'a Channel, settings: &'a Settings, user_id: i32, user_agent: &'a str, ) -> Self
Sourcepub fn plan<'life0, 'life_self, 'async_recursion>(
&'life_self self,
task: &'life0 mut Task,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_recursion>>where
'life0: 'async_recursion,
'life_self: 'async_recursion,
pub fn plan<'life0, 'life_self, 'async_recursion>(
&'life_self self,
task: &'life0 mut Task,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_recursion>>where
'life0: 'async_recursion,
'life_self: 'async_recursion,
Plan task execution
Errors
Returns error if planning is unavailable for the task status, or if there was a problem while planning the task execution.